==> haskell-ipynb-0.2-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-6qYnBlCws63JWNATz2ij13
key:                  ipynb-0.2-6qYnBlCws63JWNATz2ij13
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  ba039a20589d0227e806caddc365ef62
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-6qYnBlCws63JWNATz2ij13
depends:
    aeson-2.2.0.0-A8FqDK4tVym6hhqwC7qXFC base-4.18.2.1
    base64-bytestring-1.2.1.0-4EosDDg3uRjHJpFgdqYthW
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.2-278-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-K0CtVX4O5Cr7wF8gSRohu5
key:                  ipynb-0.2-K0CtVX4O5Cr7wF8gSRohu5
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  2786194dfe5f08675db19684e85dbd82
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-K0CtVX4O5Cr7wF8gSRohu5
depends:
    aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK base-4.18.2.1
    base64-bytestring-1.2.1.0-6srVB7ZKmzD1HZV2AV5j9d
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
